==> zombieimprovements-1.0.6%2B1.21.1-fabric-sources.jar: me/pajic/zombieimprovements/mixin/legacy/LivingEntityRendererMixin.java <==
package me.pajic.zombieimprovements.mixin.legacy;

//? if 1.21.1 {

import com.llamalad7.mixinextras.injector.ModifyExpressionValue;
import com.llamalad7.mixinextras.sugar.Local;
import dev.kikugie.fletching_table.annotation.MixinEnvironment;
import me.pajic.zombieimprovements.ZombieImprovements;
import me.pajic.zombieimprovements.util.ZombieExtension;
import net.minecraft.class_1309;
import net.minecraft.class_1642;
import net.minecraft.class_1921;
import net.minecraft.class_4587;
import net.minecraft.class_4588;
import net.minecraft.class_4597;
import net.minecraft.class_4608;
import net.minecraft.class_583;
import net.minecraft.class_922;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.Shadow;
import org.spongepowered.asm.mixin.injection.At;

@MixinEnvironment(type = MixinEnvironment.Env.CLIENT)
@Mixin(class_922.class)
public abstract class LivingEntityRendererMixin<T extends class_1309, M extends class_583<T>>  {

    @Shadow public abstract M getModel();

    @Shadow protected abstract float getBob(T livingBase, float partialTick);

    @ModifyExpressionValue(
            method = "render(Lnet/minecraft/world/entity/LivingEntity;FFLcom/mojang/blaze3d/vertex/PoseStack;Lnet/minecraft/client/renderer/MultiBufferSource;I)V",
            at = @At(
                    value = "INVOKE",
                    target = "Lnet/minecraft/world/entity/LivingEntity;isSpectator()Z"
            )
    )
    private boolean renderZombiePowerLayer(
            boolean original,
            @Local(argsOnly = true) T entity,
            @Local(argsOnly = true) class_4587 poseStack,
            @Local(argsOnly = true) class_4597 bufferSource,
            @Local(argsOnly = true, ordinal = 1) float partialTick,
            @Local(argsOnly = true) int packedLight,
            @Local(ordinal = 9) float limbSwing,
            @Local(ordinal = 8) float limbSwingAmount,
            @Local(ordinal = 4) float netHeadYaw,
            @Local(ordinal = 5) float headPitch
    ) {
        if (ZombieImprovements.CONFIG.leaderRedAura.get() && entity instanceof class_1642 zombie && ((ZombieExtension) zombie).zi$isLeader()) {
            float f = zombie.field_6012 + partialTick;
            class_583<T> entityModel = getModel();
            entityModel.method_2816(entity, limbSwing, limbSwingAmount, partialTick);
            class_4588 vertexConsumer = bufferSource.getBuffer(class_1921.method_23018(ZombieImprovements.ZOMBIE_POWER_LAYER, (f * 0.01F) % 1.0F, f * 0.01F % 1.0F));
            entityModel.method_2819(entity, limbSwing, limbSwingAmount, getBob(entity, partialTick), netHeadYaw, headPitch);
            entityModel.method_2828(poseStack, vertexConsumer, packedLight, class_4608.field_21444, -8355712);
        }
        return original;
    }
}
//?}

==> zombieimprovements-1.1.0%2B1.21.1-fabric-sources.jar: me/pajic/zombieimprovements/mixin/legacy/LivingEntityRendererMixin.java <==
package me.pajic.zombieimprovements.mixin.legacy;

//? if 1.21.1 {

import com.llamalad7.mixinextras.injector.ModifyExpressionValue;
import com.llamalad7.mixinextras.sugar.Local;
import dev.kikugie.fletching_table.annotation.MixinEnvironment;
import me.pajic.zombieimprovements.ZombieImprovements;
import me.pajic.zombieimprovements.util.AttachmentUtil;
import me.pajic.zombieimprovements.util.ModUtil;
import net.minecraft.class_1309;
import net.minecraft.class_1642;
import net.minecraft.class_1921;
import net.minecraft.class_4587;
import net.minecraft.class_4588;
import net.minecraft.class_4597;
import net.minecraft.class_4608;
import net.minecraft.class_583;
import net.minecraft.class_922;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.Shadow;
import org.spongepowered.asm.mixin.injection.At;

@MixinEnvironment(type = MixinEnvironment.Env.CLIENT)
@Mixin(class_922.class)
public abstract class LivingEntityRendererMixin<T extends class_1309, M extends class_583<T>>  {

    @Shadow public abstract M getModel();

    @Shadow protected abstract float getBob(T livingBase, float partialTick);

    @ModifyExpressionValue(
            method = "render(Lnet/minecraft/world/entity/LivingEntity;FFLcom/mojang/blaze3d/vertex/PoseStack;Lnet/minecraft/client/renderer/MultiBufferSource;I)V",
            at = @At(
                    value = "INVOKE",
                    target = "Lnet/minecraft/world/entity/LivingEntity;isSpectator()Z"
            )
    )
    private boolean renderZombiePowerLayer(
            boolean original,
            @Local(argsOnly = true) T entity,
            @Local(argsOnly = true) class_4587 poseStack,
            @Local(argsOnly = true) class_4597 bufferSource,
            @Local(argsOnly = true, ordinal = 1) float partialTick,
            @Local(argsOnly = true) int packedLight,
            @Local(ordinal = 9) float limbSwing,
            @Local(ordinal = 8) float limbSwingAmount,
            @Local(ordinal = 4) float netHeadYaw,
            @Local(ordinal = 5) float headPitch
    ) {
        if (ZombieImprovements.CONFIG.leaderRedAura.get() && entity instanceof class_1642 zombie && AttachmentUtil.isLeader(zombie)) {
            float f = zombie.field_6012 + partialTick;
            class_583<T> entityModel = getModel();
            entityModel.method_2816(entity, limbSwing, limbSwingAmount, partialTick);
            class_4588 vertexConsumer = bufferSource.getBuffer(class_1921.method_23018(ModUtil.ZOMBIE_POWER_LAYER, (f * 0.01F) % 1.0F, f * 0.01F % 1.0F));
            entityModel.method_2819(entity, limbSwing, limbSwingAmount, getBob(entity, partialTick), netHeadYaw, headPitch);
            entityModel.method_2828(poseStack, vertexConsumer, packedLight, class_4608.field_21444, -8355712);
        }
        return original;
    }
}
//?}
